/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or (at
 *  your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *  MA 02110-1301, USA.
 *
 *  Copyright © 2006 Pierre Habouzit
 */

/*
 * Copyright notice from original mutt:
 * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
 */

#include "lib-lib.h"

string_list_t *string_list_dup(const string_list_t *p) {
    string_list_t *res = NULL;
    string_list_t **last = &res;

    for (; p; p = p->next) {
        *last = string_item_new();
        (*last)->data = m_strdup(p->data);
        last = &(*last)->next;
    }

    return res;
}

int string_list_contains(const string_list_t *t, const char *s, const char *any)
{
    while (t) {
        if (!ascii_strncasecmp(s, t->data, m_strlen(t->data))
        || (any && !ascii_strcasecmp(t->data, any)))
            return 1;
        t = t->next;
    }
    return 0;
}

void string_list_add(string_list_t **list, const char *str)
{
    if (m_strisempty(str))
        return;

    while (*list) {
        if (!ascii_strcasecmp(str, (*list)->data))
            return;
        list = &(*list)->next;
    }

    *list = p_new(string_list_t, 1);
    (*list)->data = m_strdup(str);
}

void string_list_remove(string_list_t **l, const char *str)
{
    while (*l) {
        if (!ascii_strcasecmp(str, (*l)->data)) {
            string_list_t *it = string_list_pop(l);
            string_item_delete(&it);
        } else {
            l = &(*l)->next;
        }
    }
}

/* FIXME: b0rken API's, replace that at any cost */
string_list_t *mutt_add_list_n(string_list_t *head, const void *data, size_t len) {
    string_list_t *tmp;

    for (tmp = head; tmp && tmp->next; tmp = tmp->next);

    if (tmp) {
        tmp->next = p_new(string_list_t, 1);
        tmp = tmp->next;
    } else {
        head = tmp = p_new(string_list_t, 1);
    }

    tmp->data = p_dup((const char *)data, len);
    tmp->next = NULL;
    return head;
}

